==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AutoSave</name>
    <message>
        <location filename="../AutoSave.js" line="+34"/>
        <source>Load/Save</source>
        <translation>Nahrát/Uložit</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Autosave</source>
        <translation>Automatické uložení</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation type="unfinished">Automatický uložit do:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Automatické uložení selhalo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Automatické uložení je kompletní.</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>An &apos;autosave&apos; backup file for an untitled drawing was found.
Do you wish to recover it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 &apos;autosave&apos; backup files for untitled drawings were found.
Do you wish to recover them?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Recover Files?</source>
        <translation>Obnovit soubory?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnoveno</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnovit soubor?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Nelze přejmenovat soubor:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation type="unfinished">Nelze přesunout soubor:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Povolit automatické ukládání</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Interval automatického ukládání:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/AutoSave/ts/AutoSave_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AutoSave</name>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Nahrát/Uložit</translation>
    </message>
    <message>
        <location filename="../AutoSave.js" line="+35"/>
        <source>Autosave</source>
        <translation>Automatické uložení</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Autosaving to:</source>
        <translation>Automaticky uložit do:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Autosave failed:</source>
        <translation>Automatické uložení selhalo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Autosave complete.</source>
        <translation>Automatické uložení je kompletní.</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source>%n &apos;autosave&apos; backup file(s) for (an) untitled drawing(s) was/were found.
Do you wish to recover it/them?</source>
        <translation>
            <numerusform>Byly nalezeny záložní nepojmenované &apos;autosave&apos; soubory s výkresem %n.
Přejete si je obnovit?</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Recover Files?</source>
        <translation>Obnovit soubory?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Recovered</source>
        <translation>Obnoveno</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Recover File?</source>
        <translation>Obnovit soubor?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>An &apos;autosave&apos; backup file for &apos;%1&apos; exists.
Do you wish to recover it?</source>
        <translation>Existuje záložní &apos;autosave&apos; soubor pro &apos;%1&apos;.
Přejete si ho obnovit?</translation>
    </message>
    <message>
        <location line="+25"/>
        <location line="+11"/>
        <location line="+5"/>
        <source>Cannot rename file:</source>
        <translation>Nelze přejmenovat soubor:</translation>
    </message>
    <message>
        <location line="-13"/>
        <source>Moved autosave backup file to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Moved original file to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Cannot remove file:</source>
        <translation type="unfinished">Nelze přesunout soubor:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Autosave</source>
        <translation>Povolit automatické ukládání</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Autosave Interval:</source>
        <translation>Interval automatického ukládání:</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>min</source>
        <translation>min</translation>
    </message>
</context>
</TS>
